# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

from . import _utilities
import typing
# Export this package's modules as members:
from .acl_auth_method import *
from .acl_binding_rule import *
from .acl_policy import *
from .acl_role import *
from .acl_role_policy_attachment import *
from .acl_token import *
from .acl_token_policy_attachment import *
from .acl_token_role_attachment import *
from .admin_partition import *
from .agent_service import *
from .autopilot_config import *
from .catalog_entry import *
from .certificate_authority import *
from .config_entry import *
from .config_entry_service_defaults import *
from .config_entry_service_intentions import *
from .config_entry_service_resolver import *
from .config_entry_service_router import *
from .config_entry_service_splitter import *
from .config_entry_v2_exported_services import *
from .get_acl_auth_method import *
from .get_acl_policy import *
from .get_acl_role import *
from .get_acl_token import *
from .get_acl_token_secret_id import *
from .get_agent_config import *
from .get_agent_self import *
from .get_autopilot_health import *
from .get_catalog_nodes import *
from .get_catalog_service import *
from .get_catalog_services import *
from .get_config_entry import *
from .get_config_entry_v2_exported_services import *
from .get_datacenters import *
from .get_key_prefix import *
from .get_keys import *
from .get_network_area_members import *
from .get_network_segments import *
from .get_nodes import *
from .get_peering import *
from .get_peerings import *
from .get_service import *
from .get_service_health import *
from .get_services import *
from .intention import *
from .key_prefix import *
from .keys import *
from .license import *
from .namespace import *
from .namespace_policy_attachment import *
from .namespace_role_attachment import *
from .network_area import *
from .node import *
from .peering import *
from .peering_token import *
from .prepared_query import *
from .provider import *
from .service import *
from ._inputs import *
from . import outputs

# Make subpackages available:
if typing.TYPE_CHECKING:
    import pulumi_consul.config as __config
    config = __config
else:
    config = _utilities.lazy_import('pulumi_consul.config')

_utilities.register(
    resource_modules="""
[
 {
  "pkg": "consul",
  "mod": "index/aclAuthMethod",
  "fqn": "pulumi_consul",
  "classes": {
   "consul:index/aclAuthMethod:AclAuthMethod": "AclAuthMethod"
  }
 },
 {
  "pkg": "consul",
  "mod": "index/aclBindingRule",
  "fqn": "pulumi_consul",
  "classes": {
   "consul:index/aclBindingRule:AclBindingRule": "AclBindingRule"
  }
 },
 {
  "pkg": "consul",
  "mod": "index/aclPolicy",
  "fqn": "pulumi_consul",
  "classes": {
   "consul:index/aclPolicy:AclPolicy": "AclPolicy"
  }
 },
 {
  "pkg": "consul",
  "mod": "index/aclRole",
  "fqn": "pulumi_consul",
  "classes": {
   "consul:index/aclRole:AclRole": "AclRole"
  }
 },
 {
  "pkg": "consul",
  "mod": "index/aclRolePolicyAttachment",
  "fqn": "pulumi_consul",
  "classes": {
   "consul:index/aclRolePolicyAttachment:AclRolePolicyAttachment": "AclRolePolicyAttachment"
  }
 },
 {
  "pkg": "consul",
  "mod": "index/aclToken",
  "fqn": "pulumi_consul",
  "classes": {
   "consul:index/aclToken:AclToken": "AclToken"
  }
 },
 {
  "pkg": "consul",
  "mod": "index/aclTokenPolicyAttachment",
  "fqn": "pulumi_consul",
  "classes": {
   "consul:index/aclTokenPolicyAttachment:AclTokenPolicyAttachment": "AclTokenPolicyAttachment"
  }
 },
 {
  "pkg": "consul",
  "mod": "index/aclTokenRoleAttachment",
  "fqn": "pulumi_consul",
  "classes": {
   "consul:index/aclTokenRoleAttachment:AclTokenRoleAttachment": "AclTokenRoleAttachment"
  }
 },
 {
  "pkg": "consul",
  "mod": "index/adminPartition",
  "fqn": "pulumi_consul",
  "classes": {
   "consul:index/adminPartition:AdminPartition": "AdminPartition"
  }
 },
 {
  "pkg": "consul",
  "mod": "index/agentService",
  "fqn": "pulumi_consul",
  "classes": {
   "consul:index/agentService:AgentService": "AgentService"
  }
 },
 {
  "pkg": "consul",
  "mod": "index/autopilotConfig",
  "fqn": "pulumi_consul",
  "classes": {
   "consul:index/autopilotConfig:AutopilotConfig": "AutopilotConfig"
  }
 },
 {
  "pkg": "consul",
  "mod": "index/catalogEntry",
  "fqn": "pulumi_consul",
  "classes": {
   "consul:index/catalogEntry:CatalogEntry": "CatalogEntry"
  }
 },
 {
  "pkg": "consul",
  "mod": "index/certificateAuthority",
  "fqn": "pulumi_consul",
  "classes": {
   "consul:index/certificateAuthority:CertificateAuthority": "CertificateAuthority"
  }
 },
 {
  "pkg": "consul",
  "mod": "index/configEntry",
  "fqn": "pulumi_consul",
  "classes": {
   "consul:index/configEntry:ConfigEntry": "ConfigEntry"
  }
 },
 {
  "pkg": "consul",
  "mod": "index/configEntryServiceDefaults",
  "fqn": "pulumi_consul",
  "classes": {
   "consul:index/configEntryServiceDefaults:ConfigEntryServiceDefaults": "ConfigEntryServiceDefaults"
  }
 },
 {
  "pkg": "consul",
  "mod": "index/configEntryServiceIntentions",
  "fqn": "pulumi_consul",
  "classes": {
   "consul:index/configEntryServiceIntentions:ConfigEntryServiceIntentions": "ConfigEntryServiceIntentions"
  }
 },
 {
  "pkg": "consul",
  "mod": "index/configEntryServiceResolver",
  "fqn": "pulumi_consul",
  "classes": {
   "consul:index/configEntryServiceResolver:ConfigEntryServiceResolver": "ConfigEntryServiceResolver"
  }
 },
 {
  "pkg": "consul",
  "mod": "index/configEntryServiceRouter",
  "fqn": "pulumi_consul",
  "classes": {
   "consul:index/configEntryServiceRouter:ConfigEntryServiceRouter": "ConfigEntryServiceRouter"
  }
 },
 {
  "pkg": "consul",
  "mod": "index/configEntryServiceSplitter",
  "fqn": "pulumi_consul",
  "classes": {
   "consul:index/configEntryServiceSplitter:ConfigEntryServiceSplitter": "ConfigEntryServiceSplitter"
  }
 },
 {
  "pkg": "consul",
  "mod": "index/configEntryV2ExportedServices",
  "fqn": "pulumi_consul",
  "classes": {
   "consul:index/configEntryV2ExportedServices:ConfigEntryV2ExportedServices": "ConfigEntryV2ExportedServices"
  }
 },
 {
  "pkg": "consul",
  "mod": "index/intention",
  "fqn": "pulumi_consul",
  "classes": {
   "consul:index/intention:Intention": "Intention"
  }
 },
 {
  "pkg": "consul",
  "mod": "index/keyPrefix",
  "fqn": "pulumi_consul",
  "classes": {
   "consul:index/keyPrefix:KeyPrefix": "KeyPrefix"
  }
 },
 {
  "pkg": "consul",
  "mod": "index/keys",
  "fqn": "pulumi_consul",
  "classes": {
   "consul:index/keys:Keys": "Keys"
  }
 },
 {
  "pkg": "consul",
  "mod": "index/license",
  "fqn": "pulumi_consul",
  "classes": {
   "consul:index/license:License": "License"
  }
 },
 {
  "pkg": "consul",
  "mod": "index/namespace",
  "fqn": "pulumi_consul",
  "classes": {
   "consul:index/namespace:Namespace": "Namespace"
  }
 },
 {
  "pkg": "consul",
  "mod": "index/namespacePolicyAttachment",
  "fqn": "pulumi_consul",
  "classes": {
   "consul:index/namespacePolicyAttachment:NamespacePolicyAttachment": "NamespacePolicyAttachment"
  }
 },
 {
  "pkg": "consul",
  "mod": "index/namespaceRoleAttachment",
  "fqn": "pulumi_consul",
  "classes": {
   "consul:index/namespaceRoleAttachment:NamespaceRoleAttachment": "NamespaceRoleAttachment"
  }
 },
 {
  "pkg": "consul",
  "mod": "index/networkArea",
  "fqn": "pulumi_consul",
  "classes": {
   "consul:index/networkArea:NetworkArea": "NetworkArea"
  }
 },
 {
  "pkg": "consul",
  "mod": "index/node",
  "fqn": "pulumi_consul",
  "classes": {
   "consul:index/node:Node": "Node"
  }
 },
 {
  "pkg": "consul",
  "mod": "index/peering",
  "fqn": "pulumi_consul",
  "classes": {
   "consul:index/peering:Peering": "Peering"
  }
 },
 {
  "pkg": "consul",
  "mod": "index/peeringToken",
  "fqn": "pulumi_consul",
  "classes": {
   "consul:index/peeringToken:PeeringToken": "PeeringToken"
  }
 },
 {
  "pkg": "consul",
  "mod": "index/preparedQuery",
  "fqn": "pulumi_consul",
  "classes": {
   "consul:index/preparedQuery:PreparedQuery": "PreparedQuery"
  }
 },
 {
  "pkg": "consul",
  "mod": "index/service",
  "fqn": "pulumi_consul",
  "classes": {
   "consul:index/service:Service": "Service"
  }
 }
]
""",
    resource_packages="""
[
 {
  "pkg": "consul",
  "token": "pulumi:providers:consul",
  "fqn": "pulumi_consul",
  "class": "Provider"
 }
]
"""
)
