# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities
from . import outputs

address: Optional[str]
"""
The HTTP(S) API address of the agent to use. Defaults to "127.0.0.1:8500".
"""

authJwt: Optional[str]
"""
Authenticates to Consul using a JWT authentication method.
"""

caFile: Optional[str]
"""
A path to a PEM-encoded certificate authority used to verify the remote agent's certificate.
"""

caPath: Optional[str]
"""
A path to a directory of PEM-encoded certificate authority files to use to check the authenticity of client and server
connections. Can also be specified with the `CONSUL_CAPATH` environment variable.
"""

caPem: Optional[str]
"""
PEM-encoded certificate authority used to verify the remote agent's certificate.
"""

certFile: Optional[str]
"""
A path to a PEM-encoded certificate provided to the remote agent; requires use of `key_file` or `key_pem`.
"""

certPem: Optional[str]
"""
PEM-encoded certificate provided to the remote agent; requires use of `key_file` or `key_pem`.
"""

datacenter: Optional[str]
"""
The datacenter to use. Defaults to that of the agent.
"""

headers: Optional[str]
"""
A configuration block, described below, that provides additional headers to be sent along with all requests to the
Consul server. This block can be specified multiple times.
"""

httpAuth: Optional[str]
"""
HTTP Basic Authentication credentials to be used when communicating with Consul, in the format of either `user` or
`user:pass`. This may also be specified using the `CONSUL_HTTP_AUTH` environment variable.
"""

insecureHttps: Optional[bool]
"""
Boolean value to disable SSL certificate verification; setting this value to true is not recommended for production use.
Only use this with scheme set to "https".
"""

keyFile: Optional[str]
"""
A path to a PEM-encoded private key, required if `cert_file` or `cert_pem` is specified.
"""

keyPem: Optional[str]
"""
PEM-encoded private key, required if `cert_file` or `cert_pem` is specified.
"""

namespace: Optional[str]

scheme: Optional[str]
"""
The URL scheme of the agent to use ("http" or "https"). Defaults to "http".
"""

token: Optional[str]
"""
The ACL token to use by default when making requests to the agent. Can also be specified with `CONSUL_HTTP_TOKEN` or
`CONSUL_TOKEN` as an environment variable.
"""

